pub struct GptManager { /* private fields */ }Expand description
Runs a GPT device.
Implementations
Sourceimpl GptManager
impl GptManager
pub async fn new( block_proxy: BlockProxy, partitions_dir: Arc<Simple>, ) -> Result<Arc<Self>, Error>
Sourcepub async fn new_with_mapper(
block_proxy: BlockProxy,
mapper_proxy: Option<MapperProxy>,
partitions_dir: Arc<Simple>,
) -> Result<Arc<Self>, Error>
pub async fn new_with_mapper( block_proxy: BlockProxy, mapper_proxy: Option<MapperProxy>, partitions_dir: Arc<Simple>, ) -> Result<Arc<Self>, Error>
Creates a new GptManager with an optional mapper proxy and default configuration.
pub async fn new_with_config( block_proxy: BlockProxy, partitions_dir: Arc<Simple>, config: Config, ) -> Result<Arc<Self>, Error>
Sourcepub async fn new_with_config_and_mapper(
block_proxy: BlockProxy,
mapper_proxy: Option<MapperProxy>,
partitions_dir: Arc<Simple>,
config: Config,
) -> Result<Arc<Self>, Error>
pub async fn new_with_config_and_mapper( block_proxy: BlockProxy, mapper_proxy: Option<MapperProxy>, partitions_dir: Arc<Simple>, config: Config, ) -> Result<Arc<Self>, Error>
Creates a new GptManager with custom config and an optional mapper proxy.
Sourcepub async fn mapper_session_proxy(&self) -> &MapperSessionProxy
pub async fn mapper_session_proxy(&self) -> &MapperSessionProxy
Returns a reference to the parent device’s fblock::MapperSessionProxy.
Panics
Panics if the parent device was not configured with a mapper proxy.
Sourcepub fn next_partition_key(&self) -> u64
pub fn next_partition_key(&self) -> u64
Allocates and returns the next unique partition key for mapper sessions.
Sourcepub async fn register_mappings(
&self,
key: u64,
offset_map: &OffsetMap,
) -> Result<(), Error>
pub async fn register_mappings( &self, key: u64, offset_map: &OffsetMap, ) -> Result<(), Error>
Registers the extent mapping for a partition under key with the parent mapper session.
Panics
Panics if the parent device was not configured with a mapper proxy.
Sourcepub fn has_mapper(&self) -> bool
pub fn has_mapper(&self) -> bool
Returns true if this GPT instance was configured with a mapper proxy.
pub fn block_size(&self) -> u32
pub fn block_count(&self) -> u64
pub async fn create_transaction(self: &Arc<Self>) -> Result<EventPair, Status>
pub async fn commit_transaction( self: &Arc<Self>, transaction: EventPair, ) -> Result<(), Status>
pub async fn add_partition( &self, request: PartitionsManagerAddPartitionRequest, ) -> Result<(), Status>
pub async fn handle_partitions_requests( &self, gpt_index: usize, requests: PartitionRequestStream, ) -> Result<(), Status>
pub async fn handle_composite_partitions_requests( &self, gpt_indexes: Vec<usize>, requests: OverlayPartitionRequestStream, ) -> Result<(), Status>
pub async fn reset_partition_table( self: &Arc<Self>, partitions: Vec<PartitionInfo>, ) -> Result<(), Status>
pub async fn shutdown(self: Arc<Self>)