pub struct PartitionBackend { /* private fields */ }Expand description
PartitionBackend is an implementation of block_server’s Interface which is backed by a windowed view of the underlying GPT device.
Implementations
Sourceimpl PartitionBackend
impl PartitionBackend
Sourcepub fn new(partition: Arc<GptPartition>, offset_map: OffsetMap) -> Arc<Self> ⓘ
pub fn new(partition: Arc<GptPartition>, offset_map: OffsetMap) -> Arc<Self> ⓘ
If offset_map is non-empty, the partition will pass through requests using the provided
offset map. Otherwise, the partition will proxy I/O requests (and read, write, etc will
be called on this instance).
Sourcepub fn update_info(&self, info: PartitionInfo)
pub fn update_info(&self, info: PartitionInfo)
Updates the info.