pub struct GptPartition { /* private fields */ }Expand description
A single partition in a GPT device.
Implementations
Sourceimpl GptPartition
impl GptPartition
pub fn new( gpt: &Arc<GptManager>, block_client: Arc<RemoteBlockClient>, info: PartitionInfo, ) -> Arc<Self> ⓘ
pub async fn terminate(&self)
Sourcepub fn update_info(&self, info: PartitionInfo) -> PartitionInfo
pub fn update_info(&self, info: PartitionInfo) -> PartitionInfo
Replaces the partition info, returning its old value.
pub fn block_size(&self) -> u32
pub fn block_count(&self) -> u64
Sourcepub async unsafe fn attach_vmo(&self, vmo: &Vmo) -> Result<VmoId, Status>
pub async unsafe fn attach_vmo(&self, vmo: &Vmo) -> Result<VmoId, Status>
Attaches the VMO.
Safety
The caller must guarantee that the VMO is only attached once. The reason for this is that if the far end suddenly disconnects, it is not safe to assume the VMO will not be written to in any way: the VMO could be the target of an ongoing DMA transfer.
The caller must also ensure that no references are held during I/O as this would be undefined behavior. The caller may hold pointers, which does not lead to undefined behavior; Rust does not make the same assumptions as references for pointers.
pub async fn detach_vmo(&self, vmoid: VmoId) -> Result<(), Status>
pub fn open_passthrough_session(&self, session: ServerEnd<SessionMarker>)
pub fn get_info(&self) -> DeviceInfo
pub async fn read( &self, device_block_offset: u64, block_count: u32, vmo_id: &VmoId, vmo_offset: u64, opts: ReadOptions, trace_flow_id: Option<NonZero<u64>>, ) -> Result<(), Status>
pub async fn write( &self, device_block_offset: u64, block_count: u32, vmo_id: &VmoId, vmo_offset: u64, opts: WriteOptions, trace_flow_id: Option<NonZero<u64>>, ) -> Result<(), Status>
pub async fn flush( &self, trace_flow_id: Option<NonZero<u64>>, ) -> Result<(), Status>
pub async fn trim( &self, device_block_offset: u64, block_count: u32, trace_flow_id: Option<NonZero<u64>>, ) -> Result<(), Status>